summaryrefslogtreecommitdiffstats
path: root/tests
diff options
context:
space:
mode:
authorTony Mantler <nicoya@google.com>2014-01-16 09:59:39 -0800
committerTony Mantler <nicoya@google.com>2014-01-16 14:18:58 -0800
commit7e4daecc9af8d35a7118de4edb711f084110814e (patch)
tree6a14cbadab6c493afba48dc09fd104812c06270b /tests
parent018ae522d746f0b5ca6535c598e98be879b12624 (diff)
downloadandroid_packages_apps_Email-7e4daecc9af8d35a7118de4edb711f084110814e.tar.gz
android_packages_apps_Email-7e4daecc9af8d35a7118de4edb711f084110814e.tar.bz2
android_packages_apps_Email-7e4daecc9af8d35a7118de4edb711f084110814e.zip
Merge AccountSetupNames and AccountSetupOptions
Change-Id: I5946e90e56b1fc725522d41e2e33d8125900a871
Diffstat (limited to 'tests')
-rw-r--r--tests/src/com/android/email/activity/setup/AccountSetupFinalTests.java (renamed from tests/src/com/android/email/activity/setup/AccountSetupOptionsTests.java)17
1 files changed, 7 insertions, 10 deletions
diff --git a/tests/src/com/android/email/activity/setup/AccountSetupOptionsTests.java b/tests/src/com/android/email/activity/setup/AccountSetupFinalTests.java
index 300e96ea4..b1f74e2ad 100644
--- a/tests/src/com/android/email/activity/setup/AccountSetupOptionsTests.java
+++ b/tests/src/com/android/email/activity/setup/AccountSetupFinalTests.java
@@ -27,9 +27,6 @@ import android.widget.Spinner;
import android.widget.SpinnerAdapter;
import com.android.email.R;
-import com.android.email.activity.setup.AccountSetupOptions;
-import com.android.email.activity.setup.SetupDataFragment;
-import com.android.email.activity.setup.SpinnerOption;
import com.android.emailcommon.provider.Account;
import com.android.emailcommon.provider.HostAuth;
@@ -38,19 +35,19 @@ import java.net.URISyntaxException;
/**
* Tests of basic UI logic in the AccountSetupOptions screen.
* You can run this entire test case with:
* runtest -c com.android.email.activity.setup.AccountSetupOptionsTests email
*/
@Suppress
@MediumTest
-public class AccountSetupOptionsTests
- extends ActivityInstrumentationTestCase2<AccountSetupOptions> {
+public class AccountSetupFinalTests
+ extends ActivityInstrumentationTestCase2<AccountSetupFinal> {
- private AccountSetupOptions mActivity;
+ private AccountSetupFinal mActivity;
private Spinner mCheckFrequencyView;
private CheckBox mBackgroundAttachmentsView;
- public AccountSetupOptionsTests() {
- super(AccountSetupOptions.class);
+ public AccountSetupFinalTests() {
+ super(AccountSetupFinal.class);
}
/**
@@ -157,7 +154,7 @@ public class AccountSetupOptionsTests
for (int i = 0; i < sa.getCount(); ++i) {
SpinnerOption so = (SpinnerOption) sa.getItem(i);
- if (so != null && ((Integer)so.value).intValue() == value) {
+ if (so != null && ((Integer)so.value) == value) {
return true;
}
}
@@ -38,19 +35,19 @@ import java.net.URISyntaxException;
* Tests of basic UI logic in the AccountSetupOptions screen.
* You can run this entire test case with:
- * runtest -c com.android.email.activity.setup.AccountSetupOptionsTests email
+ * runtest -c com.android.email.activity.setup.AccountSetupFinalTests email
*/